@@ -1,6 +1,6 @@
 <?php
 /*
-** Copyright (C) 2001-2024 Zabbix SIA
+** Copyright (C) 2001-2026 Zabbix SIA
 **
 ** This program is free software: you can redistribute it and/or modify it under the terms of
 ** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
@@ -572,8 +572,11 @@ class CControllerPopupGeneric extends CController {
 			'monitored_hosts' =>					'in 1',
 			'templated_hosts' =>					'in 1',
 			'real_hosts' =>							'in 1',
+			'with_hosts' =>							'in 1',
 			'normal_only' =>						'in 1',
 			'with_graphs' =>						'in 1',
+			'with_hosts' =>							'in 1',
+			'with_templates' =>						'in 1',
 			'with_graph_prototypes' =>				'in 1',
 			'with_items' =>							'in 1',
 			'with_simple_graph_items' =>			'in 1',
@@ -741,6 +744,13 @@ class CControllerPopupGeneric extends CController {
 				'itemids' => $this->getInput('parent_discoveryid')
 			]);
 
+			if (!$lld_rules) {
+				$lld_rules = API::DiscoveryRulePrototype()->get([
+					'output' => [],
+					'itemids' => $this->getInput('parent_discoveryid')
+				]);
+			}
+
 			if (!$lld_rules) {
 				return false;
 			}
@@ -799,9 +809,11 @@ class CControllerPopupGeneric extends CController {
 			$host_options['monitored_hosts'] = 1;
 		}
 		elseif ($this->hasInput('real_hosts')) {
-			$group_options['with_hosts'] = 1;
 			$host_options['real_hosts'] = 1;
 		}
+		elseif ($this->hasInput('with_hosts')) {
+			$group_options['with_hosts'] = 1;
+		}
 		elseif ($this->hasInput('templated_hosts')) {
 			$host_options['templated_hosts'] = 1;
 			$templategroup_options['with_templates'] = 1;
@@ -981,7 +993,7 @@ class CControllerPopupGeneric extends CController {
 	 * @return array
 	 */
 	protected function getPageOptions(): array {
-		$option_fields_binary = ['real_hosts', 'with_items', 'writeonly'];
+		$option_fields_binary = ['real_hosts', 'with_hosts', 'with_items', 'writeonly'];
 		$option_fields_value = ['host_templates'];
 
 		$page_options = [
@@ -1268,7 +1280,7 @@ class CControllerPopupGeneric extends CController {
 
 			case 'users':
 				$options += [
-					'output' => ['userid', 'username', 'name', 'surname', 'type', 'theme', 'lang']
+					'output' => ['userid', 'username', 'name', 'surname']
 				];
 
 				if ($this->hasInput('exclude_provisioned')) {
@@ -1320,6 +1332,10 @@ class CControllerPopupGeneric extends CController {
 					];
 				}
 
+				if ($this->hasInput('normal_only')) {
+					$options['filter']['flags'] = ZBX_FLAG_DISCOVERY_NORMAL;
+				}
+
 				$records = (!$this->group_preselect_required || $this->groupids)
 					? API::Host()->get($options)
 					: [];
@@ -1349,7 +1365,7 @@ class CControllerPopupGeneric extends CController {
 					'with_triggers' => $this->hasInput('with_triggers')
 				];
 
-				if (array_key_exists('real_hosts', $this->page_options)) {
+				if (array_key_exists('with_hosts', $this->page_options)) {
 					$options['with_hosts'] = true;
 				}
 
@@ -1357,6 +1373,10 @@ class CControllerPopupGeneric extends CController {
 					$options['with_httptests'] = true;
 				}
 
+				if ($this->hasInput('with_hosts')) {
+					$options['with_hosts'] = true;
+				}
+
 				if ($this->hasInput('with_items')) {
 					$options['with_items'] = true;
 				}
@@ -1396,6 +1416,10 @@ class CControllerPopupGeneric extends CController {
 					$options['with_items'] = true;
 				}
 
+				if ($this->hasInput('with_templates')) {
+					$options['with_templates'] = true;
+				}
+
 				$records = API::TemplateGroup()->get($options);
 				if ($this->hasInput('enrich_parent_groups')) {
 					$records = enrichParentTemplateGroups($records);
@@ -1592,6 +1616,7 @@ class CControllerPopupGeneric extends CController {
 
 				if ($this->source_table === 'graph_prototypes') {
 					$options['selectDiscoveryRule'] = ['hostid'];
+					$options['selectDiscoveryRulePrototype'] = ['hostid'];
 
 					$records = (!$this->host_preselect_required || $this->hostids)
 						? API::GraphPrototype()->get($options)
