@@ -1,6 +1,6 @@
 <?php
 /*
-** Copyright (C) 2001-2024 Zabbix SIA
+** Copyright (C) 2001-2026 Zabbix SIA
 **
 ** This program is free software: you can redistribute it and/or modify it under the terms of
 ** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
@@ -19,7 +19,6 @@
  * @var array $data
  */
 
-$this->addJsFile('class.form.fieldset.collapsible.js');
 $this->includeJsFile('administration.authentication.edit.js.php');
 
 $form = (new CForm())
@@ -176,7 +175,7 @@ $ldap_tab = (new CFormGrid())
 							new CColHeader(_('Host')),
 							(new CColHeader(_('User groups')))->addClass(ZBX_STYLE_NOWRAP),
 							_('Default'),
-							''
+							_('Action')
 						]))->addClass(ZBX_STYLE_GREY)
 					)
 					->addItem(
@@ -204,7 +203,8 @@ $ldap_tab = (new CFormGrid())
 	->addItem([
 		new CLabel(_('Provisioning period'), 'jit_provision_interval'),
 		new CFormField(
-			(new CTextBox('jit_provision_interval', $data['jit_provision_interval']))
+			(new CTextBox('jit_provision_interval', $data['jit_provision_interval'], false,
+					CSettingsSchema::getFieldLength('jit_provision_interval')))
 				->setWidth(ZBX_TEXTAREA_4DIGITS_WIDTH)
 				->setEnabled($ldap_auth_enabled && $data['ldap_jit_status'] == JIT_PROVISIONING_ENABLED)
 		)
@@ -470,7 +470,10 @@ $saml_tab = (new CFormGrid())
 					->addClass($saml_auth_enabled ? null : ZBX_STYLE_DISABLED)
 					->setHeader(
 						(new CRowHeader([
-							_('Name '), _('Media type'), _('Attribute'), ''
+							_('Name'),
+							_('Media type'),
+							_('Attribute'),
+							(new CColHeader(_('Action')))->setWidth('12%')
 						]))->addClass(ZBX_STYLE_GREY)
 					)
 					->addItem(
@@ -582,7 +585,7 @@ if ($data['is_http_auth_allowed']) {
 			new CLabel(_('Remove domain name'), 'http_strip_domains'),
 			new CFormField(
 				(new CTextBox('http_strip_domains', $data['http_strip_domains'], false,
-					DB::getFieldLength('config', 'http_strip_domains')
+					CSettingsSchema::getFieldLength('http_strip_domains')
 				))
 					->setEnabled($data['http_auth_enabled'])
 					->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
