@@ -1,6 +1,6 @@
 <?php
 /*
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2026 Zabbix SIA
 **
 ** This program is free software: you can redistribute it and/or modify it under the terms of
 ** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
@@ -187,7 +187,7 @@
 				this.#addEventListeners();
 			}
 
-			this.#setSubmitCallback();
+			this.#initPopupListeners();
 		}
 
 		#activateHostDashboardNavigation() {
@@ -370,33 +370,29 @@
 				});
 		}
 
-		#setSubmitCallback() {
-			window.popupManagerInstance.setSubmitCallback((e) => {
-				let curl = null;
-				const data = e.detail;
+		#initPopupListeners() {
+			ZABBIX.EventHub.subscribe({
+				require: {
+					context: CPopupManager.EVENT_CONTEXT,
+					event: CPopupManagerEvent.EVENT_SUBMIT
+				},
+				callback: ({data, event}) => {
+					if ('error' in data.submit) {
+						if ('title' in data.submit.error) {
+							postMessageError(data.submit.error.title);
+						}
 
-				if ('success' in data) {
-					postMessageOk(data.success.title);
-
-
-					if ('messages' in data.success) {
-						postMessageDetails('success', data.success.messages);
+						postMessageDetails('error', data.submit.error.messages);
 					}
 
-					if ('action' in data.success && data.success.action === 'delete') {
-						curl = new Curl('zabbix.php');
-						curl.setArgument('action', 'host.view');
+					if (data.submit.success?.action === 'delete') {
+						const url = new URL('zabbix.php', location.href);
+
+						url.searchParams.set('action', 'host.view');
+
+						event.setRedirectUrl(url.href);
 					}
 				}
-				else {
-					postMessageError(data.error.title);
-
-					if ('messages' in data.error) {
-						postMessageDetails('error', data.error.messages);
-					}
-				}
-
-				location.href = curl === null ? location.href : curl.getUrl();
 			});
 		}
 	}
