@@ -1,6 +1,6 @@
 <?php declare(strict_types = 0);
 /*
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2026 Zabbix SIA
 **
 ** This program is free software: you can redistribute it and/or modify it under the terms of
 ** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
@@ -20,7 +20,6 @@
  */
 
 $this->includeJsFile('mediatype.list.js.php');
-$this->addJsFile('multilineinput.js');
 
 $html_page = (new CHtmlPage())
 	->setTitle(_('Media types'))
@@ -166,9 +165,6 @@ foreach ($data['mediatypes'] as $media_type) {
 
 			$actions[] = $action['is_editable']
 				? (new CLink($action['name'], $action_url))
-					->setAttribute('data-actionid', $action['actionid'])
-					->setAttribute('data-eventsource', $action['eventsource'])
-					->setAttribute('data-action', 'action.edit')
 					->addClass(ZBX_STYLE_LINK_ALT)
 					->addClass(ZBX_STYLE_GREY)
 				: (new CSpan($action['name']))->addClass(ZBX_STYLE_GREY);
@@ -207,19 +203,17 @@ foreach ($data['mediatypes'] as $media_type) {
 		->setArgument('mediatypeid', $media_type['mediatypeid'])
 		->getUrl();
 
-	$name = (new CLink($media_type['name'], $media_type_url))
-		->setAttribute('data-mediatypeid', $media_type['mediatypeid'])
-		->setAttribute('data-action', 'mediatype.edit');
+	$name = new CLink($media_type['name'], $media_type_url);
 
 	// append row
 	$media_type_table->addRow([
 		new CCheckBox('mediatypeids['.$media_type['mediatypeid'].']', $media_type['mediatypeid']),
-		(new CCol($name))->addClass(ZBX_STYLE_WORDBREAK),
+		(new CCol($name))->addClass(ZBX_STYLE_NOWRAP),
 		CMediatypeHelper::getMediaTypes($media_type['typeid']),
 		$status,
 		(new CCol($action_count_total))->addClass(ZBX_STYLE_CELL_WIDTH),
-		(new CCol($actions))->addClass(ZBX_STYLE_WORDBREAK),
-		(new CCol($details))->addClass(ZBX_STYLE_WORDBREAK),
+		$actions,
+		$details,
 		$test_link
 	]);
 }
