@@ -1,6 +1,6 @@
 <?php declare(strict_types = 0);
 /*
-** Copyright (C) 2001-2024 Zabbix SIA
+** Copyright (C) 2001-2026 Zabbix SIA
 **
 ** This program is free software: you can redistribute it and/or modify it under the terms of
 ** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
@@ -162,7 +162,7 @@ array_unshift($data['mediatype_options'], ['name' => _('All available'), 'mediat
 $mediatypes = [];
 foreach ($data['mediatype_options'] as $mediatype) {
 	$mediatypes[] = (new CSelectOption($mediatype['mediatypeid'], $mediatype['name']))
-		->addClass($mediatype['status'] == MEDIA_TYPE_STATUS_DISABLED ? ZBX_STYLE_RED : null);
+		->addClass($mediatype['status'] == MEDIA_TYPE_STATUS_DISABLED ? ZBX_STYLE_COLOR_NEGATIVE : null);
 }
 
 // Operation message media type row.
