@@ -1,6 +1,6 @@
 <?php
 /*
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2026 Zabbix SIA
 **
 ** This program is free software: you can redistribute it and/or modify it under the terms of
 ** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
@@ -212,7 +212,6 @@ abstract class CHostBase extends CApiService {
 		$is_template_update = $this instanceof CTemplate && $db_hosts !== null;
 		$double_linkage_scope = $is_template_update ? null : [];
 		$del_templates = [];
-		$del_links_clear = [];
 
 		foreach ($hosts as $host) {
 			if (array_key_exists('templates', $host)) {
@@ -272,22 +271,12 @@ abstract class CHostBase extends CApiService {
 					}
 				}
 			}
-
-			if (($this instanceof CHost || $this instanceof CTemplate) && array_key_exists('templates_clear', $host)) {
-				foreach ($host['templates_clear'] as $template) {
-					$del_links_clear[$template['templateid']][$host[$id_field_name]] = true;
-				}
-			}
 		}
 
 		if ($del_templates) {
 			$this->checkTriggerExpressionsOfDelTemplates($del_templates);
 		}
 
-		if ($del_links_clear) {
-			$this->checkTriggerDependenciesOfHostTriggers($del_links_clear);
-		}
-
 		if ($ins_templates) {
 			if ($this instanceof CTemplate && $db_hosts !== null) {
 				self::checkCircularLinkageNew($ins_templates, $del_links);
@@ -346,168 +335,6 @@ abstract class CHostBase extends CApiService {
 		}
 	}
 
-	/**
-	 * Check whether the triggers of the target hosts or templates don't have a dependencies on the triggers of the
-	 * unlinking (with cleaning) templates.
-	 *
-	 * @param array $del_links_clear[<templateid>][<hostid>]
-	 *
-	 * @throws APIException
-	 */
-	protected function checkTriggerDependenciesOfHostTriggers(array $del_links_clear): void {
-		$del_host_templates = [];
-
-		foreach ($del_links_clear as $templateid => $hosts) {
-			foreach ($hosts as $hostid => $foo) {
-				$del_host_templates[$hostid][] = $templateid;
-			}
-		}
-
-		$result = DBselect(
-			'SELECT DISTINCT i.hostid AS templateid,t.triggerid,ii.hostid'.
-			' FROM items i,functions f,triggers t,functions ff,items ii'.
-			' WHERE i.itemid=f.itemid'.
-				' AND f.triggerid=t.templateid'.
-				' AND t.triggerid=ff.triggerid'.
-				' AND ff.itemid=ii.itemid'.
-				' AND '.dbConditionId('i.hostid', array_keys($del_links_clear)).
-				' AND '.dbConditionId('ii.hostid', array_keys($del_host_templates))
-		);
-
-		$trigger_links = [];
-
-		while ($row = DBfetch($result)) {
-			if (in_array($row['templateid'], $del_host_templates[$row['hostid']])) {
-				$trigger_links[$row['triggerid']][$row['hostid']] = $row['templateid'];
-			}
-		}
-
-		if (!$trigger_links) {
-			return;
-		}
-
-		$result = DBselect(
-			'SELECT DISTINCT td.triggerid_up,td.triggerid_down,i.hostid'.
-			' FROM trigger_depends td,functions f,items i'.
-			' WHERE td.triggerid_down=f.triggerid'.
-				' AND f.itemid=i.itemid'.
-				' AND '.dbConditionId('td.triggerid_up', array_keys($trigger_links)).
-				' AND '.dbConditionId('td.triggerid_down', array_keys($trigger_links), true).
-				' AND '.dbConditionId('i.hostid', array_keys($del_host_templates))
-		);
-
-		while ($row = DBfetch($result)) {
-			foreach ($trigger_links[$row['triggerid_up']] as $hostid => $templateid) {
-				if (bccomp($row['hostid'], $hostid) == 0) {
-					$objects = DB::select('hosts', [
-						'output' => ['host', 'status'],
-						'hostids' => [$templateid, $hostid],
-						'preservekeys' => true
-					]);
-
-					$triggers = DB::select('triggers', [
-						'output' => ['description'],
-						'triggerids' => $row['triggerid_down']
-					]);
-
-					$error = ($objects[$hostid]['status'] == HOST_STATUS_TEMPLATE)
-						? _('Cannot unlink template "%1$s" from template "%2$s" due to dependency of trigger "%3$s".')
-						: _('Cannot unlink template "%1$s" from host "%2$s" due to dependency of trigger "%3$s".');
-
-					self::exception(ZBX_API_ERROR_PARAMETERS, sprintf($error, $objects[$templateid]['host'],
-						$objects[$hostid]['host'], $triggers[0]['description']
-					));
-				}
-			}
-		}
-
-		if ($this instanceof CTemplate) {
-			$trigger_hosts = [];
-
-			foreach ($trigger_links as $triggerid => $hostids) {
-				$trigger_hosts[$triggerid] = array_keys($hostids);
-			}
-
-			$trigger_map = [];
-
-			while (true) {
-				$result = DBselect(
-					'SELECT DISTINCT t.templateid,t.triggerid,i.hostid'.
-					' FROM triggers t,functions f,items i'.
-					' WHERE t.triggerid=f.triggerid'.
-						' AND f.itemid=i.itemid'.
-						' AND '.dbConditionId('t.templateid', array_keys($trigger_hosts))
-				);
-
-				$_trigger_hosts = [];
-				$hostids = [];
-
-				while ($row = DBfetch($result)) {
-					foreach ($trigger_hosts[$row['templateid']] as $hostid) {
-						if (array_key_exists($row['hostid'], $del_host_templates)
-								&& in_array($hostid, $del_host_templates[$row['hostid']])) {
-							continue;
-						}
-
-						$trigger_map[$row['triggerid']] = $row['templateid'];
-						$_trigger_hosts[$row['triggerid']][] = $row['hostid'];
-						$hostids[$row['hostid']] = true;
-					}
-				}
-
-				if (!$_trigger_hosts) {
-					break;
-				}
-
-				$trigger_hosts = $_trigger_hosts;
-
-				$result = DBselect(
-					'SELECT DISTINCT td.triggerid_up,td.triggerid_down,i.hostid'.
-					' FROM trigger_depends td,functions f,items i'.
-					' WHERE td.triggerid_down=f.triggerid'.
-						' AND f.itemid=i.itemid'.
-						' AND '.dbConditionId('td.triggerid_up', array_keys($trigger_hosts)).
-						' AND '.dbConditionId('td.triggerid_down', array_keys($trigger_hosts), true).
-						' AND '.dbConditionId('i.hostid', array_keys($hostids))
-				);
-
-				while ($row = DBfetch($result)) {
-					foreach ($trigger_hosts[$row['triggerid_up']] as $hostid) {
-						if (bccomp($row['hostid'], $hostid) == 0) {
-							$triggerid = $row['triggerid_up'];
-
-							do {
-								$triggerid = $trigger_map[$triggerid];
-							} while (array_key_exists($triggerid, $trigger_map));
-
-							$from_hostid = key($trigger_links[$triggerid]);
-							$templateid = $trigger_links[$triggerid][$from_hostid];
-
-							$objects = DB::select('hosts', [
-								'output' => ['host', 'status'],
-								'hostids' => [$templateid, $from_hostid, $hostid],
-								'preservekeys' => true
-							]);
-
-							$triggers = DB::select('triggers', [
-								'output' => ['description'],
-								'triggerids' => $row['triggerid_down']
-							]);
-
-							$error = ($objects[$hostid]['status'] == HOST_STATUS_TEMPLATE)
-								? _('Cannot unlink template "%1$s" from template "%2$s" due to dependency of trigger "%3$s" on template "%4$s".')
-								: _('Cannot unlink template "%1$s" from template "%2$s" due to dependency of trigger "%3$s" on host "%4$s".');
-
-							self::exception(ZBX_API_ERROR_PARAMETERS, sprintf($error, $objects[$templateid]['host'],
-								$objects[$from_hostid]['host'], $triggers[0]['description'], $objects[$hostid]['host']
-							));
-						}
-					}
-				}
-			}
-		}
-	}
-
 	/**
 	 * Check whether circular linkage occurs as a result of the given changes in templates links.
 	 *
