@@ -1,6 +1,6 @@
 <?php declare(strict_types = 0);
 /*
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2026 Zabbix SIA
 **
 ** This program is free software: you can redistribute it and/or modify it under the terms of
 ** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
@@ -29,6 +29,18 @@ class CWidgetFieldSeveritiesView extends CWidgetFieldView {
 			->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 			->setEnabled(!$this->isDisabled())
 			->setColumns(3)
-			->setVertical();
+			->setVertical()
+			->showTitles();
+	}
+
+	public function getJavaScript(): string {
+		return '
+			CWidgetForm.addField(
+				new CWidgetFieldSeverities('.json_encode([
+					'name' => $this->field->getName(),
+					'form_name' => $this->form_name
+				]).')
+			);
+		';
 	}
 }
