@@ -1,21 +1,16 @@
-<?php declare(strict_types = 1);
+<?php declare(strict_types = 0);
 /*
-** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2026 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -29,6 +24,11 @@ class CTemplateScreenConverter extends CConverter {
 	 */
 	private const DISPLAY_WIDTH = 1920;
 
+	private const DASHBOARD_MAX_COLUMNS = 24;
+	private const DASHBOARD_MAX_ROWS = 64;
+	private const WIDGET_MIN_ROWS = 2;
+	private const WIDGET_MAX_ROWS = 32;
+
 	/**
 	 * Widget row height on dashboard.
 	 */
@@ -39,6 +39,17 @@ class CTemplateScreenConverter extends CConverter {
 	 */
 	private const SCREEN_LEGEND_HEIGHT = 215;
 
+	/**
+	 * Legacy screen resource types.
+	 */
+	private const SCREEN_RESOURCE_TYPE_GRAPH = 0;
+	private const SCREEN_RESOURCE_TYPE_SIMPLE_GRAPH = 1;
+	private const SCREEN_RESOURCE_TYPE_PLAIN_TEXT = 3;
+	private const SCREEN_RESOURCE_TYPE_CLOCK = 7;
+	private const SCREEN_RESOURCE_TYPE_URL = 11;
+	private const SCREEN_RESOURCE_TYPE_LLD_SIMPLE_GRAPH = 19;
+	private const SCREEN_RESOURCE_TYPE_LLD_GRAPH = 20;
+
 	/**
 	 * Convert template screen definition to template dashboard definition.
 	 *
@@ -77,8 +88,8 @@ class CTemplateScreenConverter extends CConverter {
 				];
 
 				// Skip screen items not fitting on dashboard.
-				if (($widget_pos['x'] + $widget_pos['width'] > DASHBOARD_MAX_COLUMNS)
-						|| ($widget_pos['y'] + $widget_pos['height'] > DASHBOARD_MAX_ROWS)) {
+				if (($widget_pos['x'] + $widget_pos['width'] > self::DASHBOARD_MAX_COLUMNS)
+						|| ($widget_pos['y'] + $widget_pos['height'] > self::DASHBOARD_MAX_ROWS)) {
 					continue;
 				}
 
@@ -108,17 +119,16 @@ class CTemplateScreenConverter extends CConverter {
 	/**
 	 * Filter screen items by valid resourcetype.
 	 *
-	 * @static
-	 *
 	 * @param array $screen_items
 	 *
 	 * @return array  valid screen items
 	 */
 	private static function getValidScreenItems(array $screen_items): array {
 		return array_filter($screen_items, function(array $screen_item): bool {
-			return in_array($screen_item['resourcetype'], [SCREEN_RESOURCE_CLOCK, SCREEN_RESOURCE_GRAPH,
-				SCREEN_RESOURCE_SIMPLE_GRAPH, SCREEN_RESOURCE_LLD_GRAPH, SCREEN_RESOURCE_LLD_SIMPLE_GRAPH,
-				SCREEN_RESOURCE_PLAIN_TEXT, SCREEN_RESOURCE_URL
+			return in_array($screen_item['resourcetype'], [self::SCREEN_RESOURCE_TYPE_CLOCK,
+				self::SCREEN_RESOURCE_TYPE_GRAPH, self::SCREEN_RESOURCE_TYPE_SIMPLE_GRAPH,
+				self::SCREEN_RESOURCE_TYPE_LLD_GRAPH, self::SCREEN_RESOURCE_TYPE_LLD_SIMPLE_GRAPH,
+				self::SCREEN_RESOURCE_TYPE_PLAIN_TEXT, self::SCREEN_RESOURCE_TYPE_URL
 			]);
 		});
 	}
@@ -126,8 +136,6 @@ class CTemplateScreenConverter extends CConverter {
 	/**
 	 * Remove empty rows and columns and simplify rowspan and colspan usage in the screen items.
 	 *
-	 * @static
-	 *
 	 * @param array $screen_items
 	 *
 	 * @return array  Optimized screen items.
@@ -187,8 +195,6 @@ class CTemplateScreenConverter extends CConverter {
 	/**
 	 * Get final dashboard dimensions for screen table rows and columns.
 	 *
-	 * @static
-	 *
 	 * @param array $screen_items
 	 *
 	 * @return array  Dashboard dimensions
@@ -227,13 +233,17 @@ class CTemplateScreenConverter extends CConverter {
 
 		$dimensions_x_preferred = self::getAxisDimensions($items_x_preferred);
 		$dimensions_x_min = self::getAxisDimensions($items_x_min);
-		$dimensions_x = self::adjustAxisDimensions($dimensions_x_preferred, $dimensions_x_min, DASHBOARD_MAX_COLUMNS);
+		$dimensions_x = self::adjustAxisDimensions($dimensions_x_preferred, $dimensions_x_min,
+			self::DASHBOARD_MAX_COLUMNS
+		);
 
 		$dimensions_y_preferred = self::getAxisDimensions($items_y_preferred);
 		$dimensions_y_min = self::getAxisDimensions($items_y_min);
 
-		if (array_sum($dimensions_y_preferred) > DASHBOARD_MAX_ROWS) {
-			$dimensions_y = self::adjustAxisDimensions($dimensions_y_preferred, $dimensions_y_min, DASHBOARD_MAX_ROWS);
+		if (array_sum($dimensions_y_preferred) > self::DASHBOARD_MAX_ROWS) {
+			$dimensions_y = self::adjustAxisDimensions($dimensions_y_preferred, $dimensions_y_min,
+				self::DASHBOARD_MAX_ROWS
+			);
 		}
 		else {
 			$dimensions_y = $dimensions_y_preferred;
@@ -245,8 +255,6 @@ class CTemplateScreenConverter extends CConverter {
 	/**
 	 * Get axis dimensions based on prepared items.
 	 *
-	 * @static
-	 *
 	 * @param array $items                Prepared items.
 	 * @param int   $items[]['position']  Item starting position.
 	 * @param int   $items[]['span']      Item cell span.
@@ -317,9 +325,7 @@ class CTemplateScreenConverter extends CConverter {
 	/**
 	 * Adjust axis dimensions to the target summary size whether possible.
 	 *
-	 * @static
-	 *
-	 * @param array $dimensions      Prefered axis dimensions.
+	 * @param array $dimensions      Preferred axis dimensions.
 	 * @param array $dimensions_min  Minimal axis dimensions.
 	 * @param int   $target          Target summary size.
 	 *
@@ -364,8 +370,6 @@ class CTemplateScreenConverter extends CConverter {
 	/**
 	 * Get preferred widget size on dashboard for given screen item type and size.
 	 *
-	 * @static
-	 *
 	 * @param array $screen_item
 	 *
 	 * @return array
@@ -375,46 +379,54 @@ class CTemplateScreenConverter extends CConverter {
 		$height = $screen_item['height'];
 
 		// Convert graph inner height to outer height.
-		if (in_array($screen_item['resourcetype'], [SCREEN_RESOURCE_GRAPH, SCREEN_RESOURCE_SIMPLE_GRAPH,
-				SCREEN_RESOURCE_LLD_GRAPH, SCREEN_RESOURCE_LLD_SIMPLE_GRAPH])) {
+		if (in_array($screen_item['resourcetype'], [self::SCREEN_RESOURCE_TYPE_GRAPH,
+				self::SCREEN_RESOURCE_TYPE_SIMPLE_GRAPH, self::SCREEN_RESOURCE_TYPE_LLD_GRAPH,
+				self::SCREEN_RESOURCE_TYPE_LLD_SIMPLE_GRAPH])) {
 			// Transform graph screen item with height of at least 100px to occupy minimum 5 grid rows.
 			$height += self::SCREEN_LEGEND_HEIGHT;
 		}
 
+		if ($screen_item['resourcetype'] == self::SCREEN_RESOURCE_TYPE_PLAIN_TEXT) {
+			// Constants are synchronised with the same algorithm in DB upgrade patch converter.
+			$show_lines = min($screen_item['elements'], 25);
+			$rows = 2 + $show_lines / 2.5;
+		}
+		else {
+			$rows = $height / self::WIDGET_ROW_HEIGHT;
+		}
+
 		return self::limitWidgetSize([
-			'width' => round($width / self::DISPLAY_WIDTH * DASHBOARD_MAX_COLUMNS),
-			'height' => round($height / self::WIDGET_ROW_HEIGHT)
+			'width' => round($width / self::DISPLAY_WIDTH * self::DASHBOARD_MAX_COLUMNS),
+			'height' => round($rows)
 		]);
 	}
 
 	/**
 	 * Get minimal widget size on dashboard for given screen item type.
 	 *
-	 * @static
-	 *
 	 * @param int $resourcetype
 	 *
 	 * @return array
 	 */
 	private static function getMinWidgetSize(int $resourcetype): array {
 		switch ($resourcetype) {
-			case SCREEN_RESOURCE_CLOCK:
+			case self::SCREEN_RESOURCE_TYPE_CLOCK:
 				return [
 					'width' => 1,
 					'height' => 2
 				];
 
-			case SCREEN_RESOURCE_GRAPH:
-			case SCREEN_RESOURCE_SIMPLE_GRAPH:
-			case SCREEN_RESOURCE_LLD_GRAPH:
-			case SCREEN_RESOURCE_LLD_SIMPLE_GRAPH:
+			case self::SCREEN_RESOURCE_TYPE_GRAPH:
+			case self::SCREEN_RESOURCE_TYPE_SIMPLE_GRAPH:
+			case self::SCREEN_RESOURCE_TYPE_LLD_GRAPH:
+			case self::SCREEN_RESOURCE_TYPE_LLD_SIMPLE_GRAPH:
 				return [
 					'width' => 4,
 					'height' => 4
 				];
 
-			case SCREEN_RESOURCE_PLAIN_TEXT:
-			case SCREEN_RESOURCE_URL:
+			case self::SCREEN_RESOURCE_TYPE_PLAIN_TEXT:
+			case self::SCREEN_RESOURCE_TYPE_URL:
 				return [
 					'width' => 4,
 					'height' => 2
@@ -425,8 +437,6 @@ class CTemplateScreenConverter extends CConverter {
 	/**
 	 * Limit widget size not to exceed the size of dashboard.
 	 *
-	 * @static
-	 *
 	 * @param array $size
 	 * @param int   $size['width']
 	 * @param int   $size['height']
@@ -435,16 +445,14 @@ class CTemplateScreenConverter extends CConverter {
 	 */
 	private static function limitWidgetSize(array $size): array {
 		return [
-			'width' => min(DASHBOARD_MAX_COLUMNS, max(1, $size['width'])),
-			'height' => min(DASHBOARD_WIDGET_MAX_ROWS, max(DASHBOARD_WIDGET_MIN_ROWS, $size['height']))
+			'width' => min(self::DASHBOARD_MAX_COLUMNS, max(1, $size['width'])),
+			'height' => min(self::WIDGET_MAX_ROWS, max(self::WIDGET_MIN_ROWS, $size['height']))
 		];
 	}
 
 	/**
 	 * Make widget definition based on screen item.
 	 *
-	 * @static
-	 *
 	 * @param array $screen_item
 	 *
 	 * @return array  Full widget definition except the positional data.
@@ -456,7 +464,7 @@ class CTemplateScreenConverter extends CConverter {
 		];
 
 		switch ($screen_item['resourcetype']) {
-			case SCREEN_RESOURCE_CLOCK:
+			case self::SCREEN_RESOURCE_TYPE_CLOCK:
 				$widget['type'] = CXmlConstantName::DASHBOARD_WIDGET_TYPE_CLOCK;
 				$widget['fields'][] = [
 					'type' => CXmlConstantName::DASHBOARD_WIDGET_FIELD_TYPE_INTEGER,
@@ -472,7 +480,7 @@ class CTemplateScreenConverter extends CConverter {
 				}
 				break;
 
-			case SCREEN_RESOURCE_GRAPH:
+			case self::SCREEN_RESOURCE_TYPE_GRAPH:
 				$widget['type'] = CXmlConstantName::DASHBOARD_WIDGET_TYPE_GRAPH_CLASSIC;
 				$widget['fields'][] = [
 					'type' => CXmlConstantName::DASHBOARD_WIDGET_FIELD_TYPE_INTEGER,
@@ -486,7 +494,7 @@ class CTemplateScreenConverter extends CConverter {
 				];
 				break;
 
-			case SCREEN_RESOURCE_SIMPLE_GRAPH:
+			case self::SCREEN_RESOURCE_TYPE_SIMPLE_GRAPH:
 				$widget['type'] = CXmlConstantName::DASHBOARD_WIDGET_TYPE_GRAPH_CLASSIC;
 				$widget['fields'][] = [
 					'type' => CXmlConstantName::DASHBOARD_WIDGET_FIELD_TYPE_INTEGER,
@@ -500,7 +508,7 @@ class CTemplateScreenConverter extends CConverter {
 				];
 				break;
 
-			case SCREEN_RESOURCE_LLD_GRAPH:
+			case self::SCREEN_RESOURCE_TYPE_LLD_GRAPH:
 				$widget['type'] = CXmlConstantName::DASHBOARD_WIDGET_TYPE_GRAPH_PROTOTYPE;
 				$widget['fields'][] = [
 					'type' => CXmlConstantName::DASHBOARD_WIDGET_FIELD_TYPE_INTEGER,
@@ -524,7 +532,7 @@ class CTemplateScreenConverter extends CConverter {
 				];
 				break;
 
-			case SCREEN_RESOURCE_LLD_SIMPLE_GRAPH:
+			case self::SCREEN_RESOURCE_TYPE_LLD_SIMPLE_GRAPH:
 				$widget['type'] = CXmlConstantName::DASHBOARD_WIDGET_TYPE_GRAPH_PROTOTYPE;
 				$widget['fields'][] = [
 					'type' => CXmlConstantName::DASHBOARD_WIDGET_FIELD_TYPE_INTEGER,
@@ -548,7 +556,7 @@ class CTemplateScreenConverter extends CConverter {
 				];
 				break;
 
-			case SCREEN_RESOURCE_PLAIN_TEXT:
+			case self::SCREEN_RESOURCE_TYPE_PLAIN_TEXT:
 				$widget['type'] = CXmlConstantName::DASHBOARD_WIDGET_TYPE_PLAIN_TEXT;
 				$widget['fields'][] = [
 					'type' => CXmlConstantName::DASHBOARD_WIDGET_FIELD_TYPE_ITEM,
@@ -567,7 +575,7 @@ class CTemplateScreenConverter extends CConverter {
 				];
 				break;
 
-			case SCREEN_RESOURCE_URL:
+			case self::SCREEN_RESOURCE_TYPE_URL:
 				$widget['type'] = CXmlConstantName::DASHBOARD_WIDGET_TYPE_URL;
 				$widget['fields'][] = [
 					'type' => CXmlConstantName::DASHBOARD_WIDGET_FIELD_TYPE_STRING,
