@@ -1,21 +1,16 @@
 <?php
 /*
-** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2026 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -24,51 +19,27 @@
  */
 class CMacrosResolverHelper {
 
-	/**
-	 * @var CMacrosResolver
-	 */
-	private static $macrosResolver;
-
-	/**
-	 * Create CMacrosResolver object and store in static variable.
-	 *
-	 * @static
-	 */
-	private static function init() {
-		if (self::$macrosResolver === null) {
-			self::$macrosResolver = new CMacrosResolver();
-		}
-	}
-
 	/**
 	 * Resolve macros.
 	 *
-	 * @static
-	 *
 	 * @param array $options
 	 *
 	 * @return array
 	 */
 	public static function resolve(array $options) {
-		self::init();
-
-		return self::$macrosResolver->resolve($options);
+		return CMacrosResolver::resolve($options);
 	}
 
 	/**
 	 * Resolve macros in http test name.
 	 *
-	 * @static
-	 *
 	 * @param int    $hostId
 	 * @param string $name
 	 *
 	 * @return string
 	 */
 	public static function resolveHttpTestName($hostId, $name) {
-		self::init();
-
-		$macros = self::$macrosResolver->resolve([
+		$macros = CMacrosResolver::resolve([
 			'config' => 'httpTestName',
 			'data' => [$hostId => [$name]]
 		]);
@@ -79,8 +50,6 @@ class CMacrosResolverHelper {
 	/**
 	 * Resolve macros in host interfaces.
 	 *
-	 * @static
-	 *
 	 * @param array  $interfaces
 	 * @param string $interfaces[n]['hostid']
 	 * @param string $interfaces[n]['type']
@@ -98,8 +67,6 @@ class CMacrosResolverHelper {
 	 * @return array
 	 */
 	public static function resolveHostInterfaces(array $interfaces) {
-		self::init();
-
 		// agent primary ip and dns
 		$data = [];
 		foreach ($interfaces as $interface) {
@@ -109,7 +76,7 @@ class CMacrosResolverHelper {
 			}
 		}
 
-		$resolvedData = self::$macrosResolver->resolve([
+		$resolvedData = CMacrosResolver::resolve([
 			'config' => 'hostInterfaceIpDnsAgentPrimary',
 			'data' => $data
 		]);
@@ -138,7 +105,7 @@ class CMacrosResolverHelper {
 			}
 		}
 
-		$resolvedData = self::$macrosResolver->resolve([
+		$resolvedData = CMacrosResolver::resolve([
 			'config' => 'hostInterfaceIpDns',
 			'data' => $data
 		]);
@@ -164,7 +131,7 @@ class CMacrosResolverHelper {
 			$data[$interface['hostid']][] = $interface['port'];
 		}
 
-		$resolvedData = self::$macrosResolver->resolve([
+		$resolvedData = CMacrosResolver::resolve([
 			'config' => 'hostInterfacePort',
 			'data' => $data
 		]);
@@ -216,27 +183,27 @@ class CMacrosResolverHelper {
 			}
 		}
 
-		$resolved_securityname = self::$macrosResolver->resolve([
+		$resolved_securityname = CMacrosResolver::resolve([
 			'config' => 'hostInterfaceDetailsSecurityname',
 			'data' => $data['securityname']
 		]);
 
-		$resolved_authpassphrase = self::$macrosResolver->resolve([
+		$resolved_authpassphrase = CMacrosResolver::resolve([
 			'config' => 'hostInterfaceDetailsAuthPassphrase',
 			'data' => $data['authpassphrase']
 		]);
 
-		$resolved_privpassphrase = self::$macrosResolver->resolve([
+		$resolved_privpassphrase = CMacrosResolver::resolve([
 			'config' => 'hostInterfaceDetailsPrivPassphrase',
 			'data' => $data['privpassphrase']
 		]);
 
-		$resolved_contextname = self::$macrosResolver->resolve([
+		$resolved_contextname = CMacrosResolver::resolve([
 			'config' => 'hostInterfaceDetailsContextName',
 			'data' => $data['contextname']
 		]);
 
-		$resolved_community = self::$macrosResolver->resolve([
+		$resolved_community = CMacrosResolver::resolve([
 			'config' => 'hostInterfaceDetailsCommunity',
 			'data' => $data['community']
 		]);
@@ -273,41 +240,29 @@ class CMacrosResolverHelper {
 	/**
 	 * Resolve macros in trigger name.
 	 *
-	 * @static
-	 *
 	 * @param array $trigger
 	 *
 	 * @return string
 	 */
 	public static function resolveTriggerName(array $trigger) {
-		$triggers = self::resolveTriggerNames([$trigger['triggerid'] => $trigger]);
-
-		return $triggers[$trigger['triggerid']]['description'];
+		return self::resolveTriggerNames([$trigger['triggerid'] => $trigger])[$trigger['triggerid']]['description'];
 	}
 
 	/**
 	 * Resolve macros in trigger names.
 	 *
-	 * @static
-	 *
 	 * @param array $triggers
 	 * @param bool  $references_only
 	 *
 	 * @return array
 	 */
 	public static function resolveTriggerNames(array $triggers, $references_only = false) {
-		self::init();
-
-		return self::$macrosResolver->resolveTriggerNames($triggers, [
-			'references_only' => $references_only
-		]);
+		return CMacrosResolver::resolveTriggerNames($triggers, ['references_only' => $references_only]);
 	}
 
 	/**
 	 * Resolve macros in trigger operational data.
 	 *
-	 * @static
-	 *
 	 * @param array  $trigger
 	 * @param string $trigger['expression']
 	 * @param string $trigger['opdata']
@@ -321,18 +276,14 @@ class CMacrosResolverHelper {
 	 * @return string
 	 */
 	public static function resolveTriggerOpdata(array $trigger, array $options = []) {
-		$triggers = self::resolveTriggerDescriptions([$trigger['triggerid'] => $trigger],
+		return self::resolveTriggerDescriptions([$trigger['triggerid'] => $trigger],
 			$options + ['sources' => ['opdata']]
-		);
-
-		return $triggers[$trigger['triggerid']]['opdata'];
+		)[$trigger['triggerid']]['opdata'];
 	}
 
 	/**
 	 * Resolve macros in trigger description.
 	 *
-	 * @static
-	 *
 	 * @param array  $trigger
 	 * @param string $trigger['expression']
 	 * @param string $trigger['comments']
@@ -346,23 +297,19 @@ class CMacrosResolverHelper {
 	 * @return string
 	 */
 	public static function resolveTriggerDescription(array $trigger, array $options = []) {
-		$triggers = self::resolveTriggerDescriptions([$trigger['triggerid'] => $trigger],
+		return self::resolveTriggerDescriptions([$trigger['triggerid'] => $trigger],
 			$options + ['sources' => ['comments']]
-		);
-
-		return $triggers[$trigger['triggerid']]['comments'];
+		)[$trigger['triggerid']]['comments'];
 	}
 
 	/**
 	 * Resolve macros in trigger descriptions and operational data.
 	 *
-	 * @static
-	 *
 	 * @param array  $triggers
-	 * @param string $triggers[$triggerid]['expression']
-	 * @param string $triggers[$triggerid][<sources>]     See $options['sources'].
-	 * @param int    $triggers[$triggerid]['clock']       (optional)
-	 * @param int    $triggers[$triggerid]['ns']          (optional)
+	 * @param string $triggers[<triggerid>]['expression']
+	 * @param string $triggers[<triggerid>][<sources>]     See $options['sources'].
+	 * @param int    $triggers[<triggerid>]['clock']       (optional)
+	 * @param int    $triggers[<triggerid>]['ns']          (optional)
 	 * @param array  $options
 	 * @param bool   $options['events']                   (optional) Resolve {ITEM.VALUE} macro using 'clock' and 'ns'
 	 *                                                    fields. Default: false.
@@ -371,22 +318,18 @@ class CMacrosResolverHelper {
 	 *
 	 * @return array
 	 */
-	public static function resolveTriggerDescriptions(array $triggers, array $options = []) {
-		self::init();
-
+	public static function resolveTriggerDescriptions(array $triggers, array $options): array {
 		$options += [
 			'events' => false,
 			'html' => false
 		];
 
-		return self::$macrosResolver->resolveTriggerDescriptions($triggers, $options);
+		return CMacrosResolver::resolveTriggerDescriptions($triggers, $options);
 	}
 
 	/**
 	 * Resolve macros in trigger url.
 	 *
-	 * @static
-	 *
 	 * @param array  $trigger
 	 * @param string $trigger['triggerid']
 	 * @param string $trigger['expression']
@@ -397,16 +340,28 @@ class CMacrosResolverHelper {
 	 * @return bool
 	 */
 	public static function resolveTriggerUrl(array $trigger, &$url) {
-		self::init();
+		return CMacrosResolver::resolveTriggerUrl($trigger, $url, ['source' => 'url']);
+	}
 
-		return self::$macrosResolver->resolveTriggerUrl($trigger, $url);
+	/**
+	 * Resolve macros in trigger url name.
+	 *
+	 * @param array  $trigger
+	 * @param string $trigger['triggerid']
+	 * @param string $trigger['expression']
+	 * @param string $trigger['url_name']
+	 * @param string $trigger['eventid']
+	 * @param string $url
+	 *
+	 * @return bool
+	 */
+	public static function resolveTriggerUrlName(array $trigger, &$url_name) {
+		return CMacrosResolver::resolveTriggerUrl($trigger, $url_name, ['source' => 'url_name']);
 	}
 
 	/**
 	 * Resolve macros in trigger expression.
 	 *
-	 * @static
-	 *
 	 * @param string $expression
 	 * @param array  $options     See CMacrosResolver::resolveTriggerExpressions() for more details.
 	 *                            'sources' is not supported here.
@@ -414,155 +369,102 @@ class CMacrosResolverHelper {
 	 * @return string
 	 */
 	public static function resolveTriggerExpression($expression, array $options = []) {
-		self::init();
-
-		return self::$macrosResolver->resolveTriggerExpressions(
-			[['expression' => $expression]], $options
-		)[0]['expression'];
+		return CMacrosResolver::resolveTriggerExpressions([['expression' => $expression]], $options)[0]['expression'];
 	}
 
 	/**
 	 * Resolve macros in trigger expressions.
 	 *
-	 * @static
-	 *
 	 * @param array $triggers
 	 * @param array $options   See CMacrosResolver::resolveTriggerExpressions() for more details.
 	 *
 	 * @return array
 	 */
 	public static function resolveTriggerExpressions(array $triggers, array $options = []) {
-		self::init();
-
-		return self::$macrosResolver->resolveTriggerExpressions($triggers, $options);
+		return CMacrosResolver::resolveTriggerExpressions($triggers, $options);
 	}
 
 	/**
-	 * Resolve positional macros and functional item macros, for example, {{HOST.HOST1}:key.func(param)}.
+	 * Resolve expression macros. For example, {?func(/host/key, param)} or {?func(/{HOST.HOST1}/key, param)}.
 	 *
-	 * @static
+	 * @param string $name
+	 * @param array  $items
+	 * @param string $items[]['hostid']
+	 * @param string $items[]['host']
 	 *
-	 * @param type   $name					string in which macros should be resolved
-	 * @param array  $items					list of graph items
-	 * @param int    $items[n]['hostid']	graph n-th item corresponding host Id
-	 * @param string $items[n]['host']		graph n-th item corresponding host name
-	 *
-	 * @return string	string with macros replaced with corresponding values
+	 * @return string  A graph name with resolved macros.
 	 */
 	public static function resolveGraphName($name, array $items) {
-		self::init();
-
-		$graph = self::$macrosResolver->resolve([
-			'config' => 'graphName',
-			'data' => [['name' => $name, 'items' => $items]]
-		]);
-		$graph = reset($graph);
-
-		return $graph['name'];
+		return CMacrosResolver::resolveGraphNames([['name' => $name, 'items' => $items]])[0]['name'];
 	}
 
 	/**
-	 * Resolve positional macros and functional item macros, for example, {{HOST.HOST1}:key.func(param)}.
-	 * ! if same graph will be passed more than once only name for first entry will be resolved.
+	 * Resolve expression macros. For example, {?func(/host/key, param)} or {?func(/{HOST.HOST1}/key, param)}.
 	 *
-	 * @static
+	 * @param array  $graphs
+	 * @param string $graphs[]['graphid']
+	 * @param string $graphs[]['name']
 	 *
-	 * @param array  $data					list or hashmap of graphs
-	 * @param int    $data[n]['graphid']	id of graph
-	 * @param string $data[n]['name']		name of graph
-	 *
-	 * @return array	inputted data with resolved names
+	 * @return array	Inputted data with resolved graph name.
 	 */
-	public static function resolveGraphNameByIds(array $data) {
-		self::init();
+	public static function resolveGraphNameByIds(array $graphs) {
+		$_graphs = [];
 
-		$graphIds = [];
-		$graphMap = [];
-		foreach ($data as $graph) {
-			// skip graphs without macros
-			if (strpos($graph['name'], '{') !== false) {
-				$graphMap[$graph['graphid']] = [
+		foreach ($graphs as $graph) {
+			// Skip graphs without expression macros.
+			if (strpos($graph['name'], '{?') !== false) {
+				$_graphs[$graph['graphid']] = [
 					'graphid' => $graph['graphid'],
 					'name' => $graph['name'],
 					'items' => []
 				];
-				$graphIds[$graph['graphid']] = $graph['graphid'];
 			}
 		}
 
+		if (!$_graphs) {
+			return $graphs;
+		}
+
 		$items = DBfetchArray(DBselect(
-			'SELECT i.hostid,gi.graphid,h.host'.
+			'SELECT gi.graphid,h.host'.
 			' FROM graphs_items gi,items i,hosts h'.
 			' WHERE gi.itemid=i.itemid'.
 				' AND i.hostid=h.hostid'.
-				' AND '.dbConditionInt('gi.graphid', $graphIds).
+				' AND '.dbConditionInt('gi.graphid', array_keys($_graphs)).
 			' ORDER BY gi.sortorder'
 		));
 
 		foreach ($items as $item) {
-			$graphMap[$item['graphid']]['items'][] = ['hostid' => $item['hostid'], 'host' => $item['host']];
+			$_graphs[$item['graphid']]['items'][] = ['host' => $item['host']];
 		}
 
-		$graphMap = self::$macrosResolver->resolve([
-			'config' => 'graphName',
-			'data' => $graphMap
-		]);
+		$_graphs = CMacrosResolver::resolveGraphNames($_graphs);
 
-		$resolvedGraph = reset($graphMap);
-		foreach ($data as &$graph) {
-			if ($resolvedGraph && $graph['graphid'] === $resolvedGraph['graphid']) {
-				$graph['name'] = $resolvedGraph['name'];
-				$resolvedGraph = next($graphMap);
+		foreach ($graphs as &$graph) {
+			if (array_key_exists($graph['graphid'], $_graphs)) {
+				$graph['name'] = $_graphs[$graph['graphid']]['name'];
 			}
 		}
 		unset($graph);
 
-		return $data;
-	}
-
-	/**
-	 * Resolve item name macros to "name_expanded" field.
-	 *
-	 * @static
-	 *
-	 * @param array  $items
-	 * @param string $items[n]['itemid']
-	 * @param string $items[n]['hostid']
-	 * @param string $items[n]['name']
-	 * @param string $items[n]['key_']				item key (optional)
-	 *												but is (mandatory) if macros exist and "key_expanded" is not present
-	 * @param string $items[n]['key_expanded']		expanded item key (optional)
-	 *
-	 * @return array
-	 */
-	public static function resolveItemNames(array $items) {
-		self::init();
-
-		return self::$macrosResolver->resolveItemNames($items);
+		return $graphs;
 	}
 
 	/**
 	 * Resolve item key macros to "key_expanded" field.
 	 *
-	 * @static
-	 *
 	 * @param array  $items
-	 * @param string $items[n]['itemid']
-	 * @param string $items[n]['hostid']
-	 * @param string $items[n]['key_']
+	 * @param string $items[<itemid>]['hostid']
+	 * @param string $items[<itemid>]['key_']
 	 *
 	 * @return array
 	 */
 	public static function resolveItemKeys(array $items) {
-		self::init();
-
-		return self::$macrosResolver->resolveItemKeys($items);
+		return CMacrosResolver::resolveItemKeys($items);
 	}
 
 	/**
-	 * Resolve macros in item description.
-	 *
-	 * @static
+	 * Resolve item description macros to "description_expanded" field.
 	 *
 	 * @param array	 $items
 	 * @param string $items[n]['hostid']
@@ -571,56 +473,73 @@ class CMacrosResolverHelper {
 	 * @return array
 	 */
 	public static function resolveItemDescriptions(array $items): array {
-		self::init();
-
-		return self::$macrosResolver->resolveItemDescriptions($items);
+		return CMacrosResolver::resolveItemDescriptions($items);
 	}
 
 	/**
-	 * Resolve function parameter macros to "parameter_expanded" field.
+	 * Resolve macros in fields of item-based widgets.
 	 *
-	 * @static
+	 * @param array  $items
+	 *        string $items[<itemid>]['hostid']
+	 *        string $items[<itemid>][<source_field>]  Particular source field, as referred by $fields.
 	 *
-	 * @param array  $data
-	 * @param string $data[n]['hostid']
-	 * @param string $data[n]['parameter']
+	 * @param array  $fields                           Fields to resolve as [<source_field> => <resolved_field>].
 	 *
 	 * @return array
 	 */
-	public static function resolveFunctionParameters(array $data) {
-		self::init();
-
-		return self::$macrosResolver->resolveFunctionParameters($data);
+	public static function resolveItemBasedWidgetMacros(array $items, array $fields): array {
+		return CMacrosResolver::resolveItemBasedWidgetMacros($items, $fields);
 	}
 
 	/**
-	 * Expand functional macros in given map label.
+	 * Resolve text-type column macros for top-hosts widget.
 	 *
-	 * @param string $label			label to expand
-	 * @param array  $replaceHosts	list of hosts in order which they appear in trigger expression if trigger label is
-	 * given, or single host when host label is given
+	 * @param array $columns
+	 * @param array $hostids
 	 *
-	 * @return string
+	 * @return array
 	 */
-	public static function resolveMapLabelMacros($label, array $replaceHosts = []) {
-		self::init();
+	public static function resolveWidgetTopHostsTextColumns(array $columns, array $hostids): array {
+		return CMacrosResolver::resolveWidgetTopHostsTextColumns($columns, $hostids);
+	}
 
-		return self::$macrosResolver->resolveMapLabelMacros($label, $replaceHosts);
+	/**
+	 * Expand functional macros in given map link labels.
+	 *
+	 * @param array  $links
+	 * @param string $links[]['label']
+	 * @param array  $fields            A mapping between source and destination fields.
+	 *
+	 * @return array
+	 */
+	public static function resolveMapLinkLabelMacros(array $links, array $fields = ['label' => 'label']): array {
+		return CMacrosResolver::resolveMapLinkLabelMacros($links, $fields);
+	}
+
+	/**
+	 * Expand functional macros in given map shape labels.
+	 *
+	 * @param string $map_name
+	 * @param array  $shapes
+	 * @param string $shapes[]['text']
+	 * @param array  $fields            A mapping between source and destination fields.
+	 *
+	 * @return array
+	 */
+	public static function resolveMapShapeLabelMacros(string $map_name, array $shapes,
+			array $fields = ['text' => 'text']): array {
+		return CMacrosResolver::resolveMapShapeLabelMacros($map_name, $shapes, $fields);
 	}
 
 	/**
 	 * Resolve macros in dashboard widget URL.
 	 *
-	 * @static
-	 *
 	 * @param array $widget
 	 *
 	 * @return string
 	 */
 	public static function resolveWidgetURL(array $widget) {
-		self::init();
-
-		$macros = self::$macrosResolver->resolve([
+		$macros = CMacrosResolver::resolve([
 			'config' => $widget['config'],
 			'data' => [
 				$widget['hostid'] => [
@@ -636,49 +555,39 @@ class CMacrosResolverHelper {
 	/**
 	 * Resolve time unit macros.
 	 *
-	 * @static
-	 *
 	 * @param array $data
 	 * @param array $field_names
 	 *
 	 * @return array
 	 */
 	public static function resolveTimeUnitMacros(array $data, array $field_names) {
-		self::init();
-
-		return self::$macrosResolver->resolveTimeUnitMacros($data, ['sources' => $field_names]);
+		return CMacrosResolver::resolveTimeUnitMacros($data, ['sources' => $field_names]);
 	}
 
 	/**
 	 * Resolve supported macros used in map element label as well as in URL names and values.
 	 *
-	 * @static
-	 *
-	 * @param array        $selements[]
-	 * @param int          $selements[]['elementtype']          Map element type.
-	 * @param int          $selements[]['elementsubtype']       Map element subtype.
-	 * @param string       $selements[]['label']                Map element label.
-	 * @param array        $selements[]['urls']                 Map element urls.
-	 * @param string       $selements[]['urls'][]['name']       Map element url name.
-	 * @param string       $selements[]['urls'][]['url']        Map element url value.
-	 * @param int | array  $selements[]['elementid']            Element id linked to map element.
-	 * @param array        $options
-	 * @param bool         $options['resolve_element_urls']     Resolve macros in map element url name and value.
-	 * @param bool         $options['resolve_element_label']    Resolve macros in map element label.
+	 * @param array  $selements[]
+	 * @param int    $selements[]['elementtype']        Map element type.
+	 * @param int    $selements[]['elementsubtype']     Map element subtype.
+	 * @param array  $selements[]['elements']           List of objects with element IDs.
+	 * @param string $selements[]['label']              Map element label.
+	 * @param array  $selements[]['urls']               Map element urls.
+	 * @param string $selements[]['urls'][]['name']     Map element url name.
+	 * @param string $selements[]['urls'][]['url']      Map element url value.
+	 * @param array  $options
+	 * @param bool   $options['resolve_element_urls']   Resolve macros in map element url name and value.
+	 * @param bool   $options['resolve_element_label']  Resolve macros in map element label.
 	 *
 	 * @return array
 	 */
 	public static function resolveMacrosInMapElements(array $selements, array $options) {
-		self::init();
-
-		return self::$macrosResolver->resolveMacrosInMapElements($selements, $options);
+		return CMacrosResolver::resolveMacrosInMapElements($selements, $options);
 	}
 
 	/**
 	 * Set every trigger items array elements order by item usage order in trigger expression and recovery expression.
 	 *
-	 * @static
-	 *
 	 * @param array  $triggers                            Array of triggers.
 	 * @param string $triggers[]['expression']            Trigger expression used to define order of trigger items.
 	 * @param string $triggers[]['recovery_expression']   Trigger expression used to define order of trigger items.
@@ -688,9 +597,7 @@ class CMacrosResolverHelper {
 	 * @return array
 	 */
 	public static function sortItemsByExpressionOrder(array $triggers) {
-		self::init();
-
-		return self::$macrosResolver->sortItemsByExpressionOrder($triggers);
+		return CMacrosResolver::sortItemsByExpressionOrder($triggers);
 	}
 
 	/**
@@ -712,9 +619,7 @@ class CMacrosResolverHelper {
 	 * @return array
 	 */
 	public static function extractItemTestMacros(array $data) {
-		self::init();
-
-		return self::$macrosResolver->extractItemTestMacros($data);
+		return CMacrosResolver::extractItemTestMacros($data);
 	}
 
 	/**
@@ -731,8 +636,43 @@ class CMacrosResolverHelper {
 	 * @return array
 	 */
 	public static function resolveMediaTypeUrls(array $events, array $urls) {
-		self::init();
+		return CMacrosResolver::resolveMediaTypeUrls($events, $urls);
+	}
 
-		return self::$macrosResolver->resolveMediaTypeUrls($events, $urls);
+	/**
+	 * Resolve macros for manual host action scripts. Resolves host macros, interface macros, inventory, user macros
+	 * and user data macros.
+	 *
+	 * @param array  $data                          Array of unresolved macros.
+	 * @param array  $data[<hostid>]                Array of scripts. Contains script ID as keys.
+	 * @param array  $data[<hostid>][<scriptid>]    Script fields to resolve macros for.
+	 * @param array  $manualinput_values
+	 * @param string $manualinput_values[<hostid>]  Value for resolving {MANUALINPUT} macros.
+	 *
+	 * @return array
+	 */
+	public static function resolveManualHostActionScripts(array $data, array $manualinput_values = []): array {
+		return CMacrosResolver::resolveManualHostActionScripts($data, $manualinput_values);
+	}
+
+	/**
+	 * Resolve macros for manual event action scripts. Resolves host<1-9> macros, interface<1-9> macros,
+	 * inventory<1-9> macros, user macros, event macros and user data macros.
+	 *
+	 * @param array  $data                                  Array of unresolved macros.
+	 * @param array  $data[<eventid>]                       Array of scripts. Contains script ID as keys.
+	 * @param array  $data[<eventid>][<scriptid>]           Script fields to resolve macros for.
+	 * @param array  $events                                Array of events.
+	 * @param array  $events[<eventid>]                     Event fields.
+	 * @param array  $events[<eventid>][hosts]              Array of hosts that created the event.
+	 * @param array  $events[<eventid>][hosts][][<hostid>]  Host ID.
+	 * @param array  $events[<eventid>][objectid]           Trigger ID.
+	 * @param array  $manualinput_values
+	 * @param string $manualinput_values[<eventid>]         Value for resolving {MANUALINPUT} macros.
+	 * @return array
+	 */
+	public static function resolveManualEventActionScripts(array $data, array $events,
+			array $manualinput_values = []): array {
+		return CMacrosResolver::resolveManualEventActionScripts($data, $events, $manualinput_values);
 	}
 }
