@@ -1,6 +1,6 @@
 <?php declare(strict_types = 0);
 /*
-** Copyright (C) 2001-2024 Zabbix SIA
+** Copyright (C) 2001-2026 Zabbix SIA
 **
 ** This program is free software: you can redistribute it and/or modify it under the terms of
 ** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
@@ -23,7 +23,7 @@ class CWidgetFieldTimeZone extends CWidgetFieldSelect {
 	public const DEFAULT_VIEW = \CWidgetFieldTimeZoneView::class;
 	public const DEFAULT_VALUE = '';
 
-	public function __construct(string $name, string $label = null, array $values = null) {
+	public function __construct(string $name, ?string $label = null, ?array $values = null) {
 		parent::__construct($name, $label, $values === null
 			? [
 				ZBX_DEFAULT_TIMEZONE => CTimezoneHelper::getTitle(CTimezoneHelper::getSystemTimezone(),
