@@ -1,21 +1,16 @@
 <?php
 /*
-** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2026 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -493,6 +488,10 @@ function getHostInterface(?array $interface): string {
 		return '';
 	}
 
+	if ($interface['type'] == INTERFACE_TYPE_AGENT_ACTIVE) {
+		return _('Active checks');
+	}
+
 	if ($interface['useip'] == INTERFACE_USE_IP) {
 		$ip_or_dns = (filter_var($interface['ip'], FILTER_VALIDATE_IP, FILTER_FLAG_IPV6) !== false)
 			? '['.$interface['ip'].']'
@@ -505,18 +504,6 @@ function getHostInterface(?array $interface): string {
 	return $ip_or_dns.':'.$interface['port'];
 }
 
-function get_hostgroup_by_groupid($groupid) {
-	$groups = DBfetch(DBselect('SELECT g.* FROM hstgrp g WHERE g.groupid='.zbx_dbstr($groupid)));
-
-	if ($groups) {
-		return $groups;
-	}
-
-	error(_s('No host groups with groupid "%1$s".', $groupid));
-
-	return false;
-}
-
 function get_host_by_itemid($itemids) {
 	$res_array = is_array($itemids);
 	zbx_value2array($itemids);
@@ -555,7 +542,7 @@ function get_host_by_hostid($hostid, $no_error_message = 0) {
 	}
 
 	if ($no_error_message == 0) {
-		error(_s('No host with hostid "%1$s".', $hostid));
+		error(_s('No host with host ID "%1$s".', $hostid));
 	}
 
 	return false;
@@ -596,6 +583,7 @@ function getHostPrototypeParentTemplates(array $host_prototypes) {
 		$db_host_prototypes = API::HostPrototype()->get([
 			'output' => ['hostid', 'templateid'],
 			'selectDiscoveryRule' => ['itemid'],
+			'selectDiscoveryRulePrototype' => ['itemid'],
 			'selectParentHost' => ['hostid'],
 			'hostids' => array_keys($parent_host_prototypeids)
 		]);
@@ -606,7 +594,9 @@ function getHostPrototypeParentTemplates(array $host_prototypes) {
 		foreach ($db_host_prototypes as $db_host_prototype) {
 			$data['templates'][$db_host_prototype['parentHost']['hostid']] = [];
 			$hostids[$db_host_prototype['hostid']] = $db_host_prototype['parentHost']['hostid'];
-			$lld_ruleids[$db_host_prototype['hostid']] = $db_host_prototype['discoveryRule']['itemid'];
+
+			$parent_lld = $db_host_prototype['discoveryRule'] ?: $db_host_prototype['discoveryRulePrototype'];
+			$lld_ruleids[$db_host_prototype['hostid']] = $parent_lld['itemid'];
 
 			if ($db_host_prototype['templateid'] != 0) {
 				if (!array_key_exists($db_host_prototype['templateid'], $all_parent_host_prototypeids)) {
@@ -688,14 +678,14 @@ function makeHostPrototypeTemplatePrefix($host_prototypeid, array $parent_templa
 	$template = $parent_templates['templates'][$parent_templates['links'][$host_prototypeid]['parent_hostid']];
 
 	if ($provide_links && $template['permission'] == PERM_READ_WRITE) {
-		$name = (new CLink(CHtml::encode($template['name']),
+		$name = (new CLink($template['name'],
 			(new CUrl('host_prototypes.php'))
 				->setArgument('parent_discoveryid', $parent_templates['links'][$host_prototypeid]['lld_ruleid'])
 				->setArgument('context', 'template')
 		))->addClass(ZBX_STYLE_LINK_ALT);
 	}
 	else {
-		$name = new CSpan(CHtml::encode($template['name']));
+		$name = new CSpan($template['name']);
 	}
 
 	return [$name->addClass(ZBX_STYLE_GREY), NAME_DELIMITER];
@@ -717,7 +707,7 @@ function makeHostPrototypeTemplatesHtml($host_prototypeid, array $parent_templat
 		$template = $parent_templates['templates'][$parent_templates['links'][$host_prototypeid]['parent_hostid']];
 
 		if ($provide_links && $template['permission'] == PERM_READ_WRITE) {
-			$name = new CLink(CHtml::encode($template['name']),
+			$name = new CLink($template['name'],
 				(new CUrl('host_prototypes.php'))
 					->setArgument('form', 'update')
 					->setArgument('parent_discoveryid', $parent_templates['links'][$host_prototypeid]['lld_ruleid'])
@@ -726,10 +716,10 @@ function makeHostPrototypeTemplatesHtml($host_prototypeid, array $parent_templat
 			);
 		}
 		else {
-			$name = (new CSpan(CHtml::encode($template['name'])))->addClass(ZBX_STYLE_GREY);
+			$name = (new CSpan($template['name']))->addClass(ZBX_STYLE_GREY);
 		}
 
-		array_unshift($list, $name, '&nbsp;&rArr;&nbsp;');
+		array_unshift($list, $name, [NBSP(), RARR(), NBSP()]);
 
 		$host_prototypeid = $parent_templates['links'][$host_prototypeid]['hostid'];
 	}
@@ -741,73 +731,6 @@ function makeHostPrototypeTemplatesHtml($host_prototypeid, array $parent_templat
 	return $list;
 }
 
-/**
- * Get host ids of hosts which $groupids can be unlinked from.
- * if $hostids is passed, function will check only these hosts.
- *
- * @param array $groupids
- * @param array $hostids
- *
- * @return array
- */
-function getUnlinkableHostIds(array $groupIds, array $hostIds) {
-	if (!$hostIds) {
-		return [];
-	}
-
-	$dbResult = DBselect(
-		'SELECT hg.hostid'.
-		' FROM hosts_groups hg'.
-		' WHERE '.dbConditionInt('hg.groupid', $groupIds, true).
-			' AND '.dbConditionInt('hg.hostid', $hostIds).
-		' GROUP BY hg.hostid'
-	);
-
-	$unlinkableHostIds = [];
-	while ($dbRow = DBfetch($dbResult)) {
-		$unlinkableHostIds[] = $dbRow['hostid'];
-	}
-
-	return $unlinkableHostIds;
-}
-
-function getDeletableHostGroupIds(array $groupIds) {
-	// selecting the list of hosts linked to the host groups
-	$dbResult = DBselect(
-		'SELECT hg.hostid'.
-		' FROM hosts_groups hg'.
-		' WHERE '.dbConditionInt('hg.groupid', $groupIds)
-	);
-
-	$linkedHostIds = [];
-	while ($dbRow = DBfetch($dbResult)) {
-		$linkedHostIds[] = $dbRow['hostid'];
-	}
-
-	// the list of hosts which can be unlinked from the host groups
-	$hostIds = getUnlinkableHostIds($groupIds, $linkedHostIds);
-
-	$dbResult = DBselect(
-		'SELECT g.groupid'.
-		' FROM hstgrp g'.
-		' WHERE g.internal='.ZBX_NOT_INTERNAL_GROUP.
-			' AND '.dbConditionInt('g.groupid', $groupIds).
-			' AND NOT EXISTS ('.
-				'SELECT NULL'.
-				' FROM hosts_groups hg'.
-				' WHERE g.groupid=hg.groupid'.
-					($hostIds ? ' AND '.dbConditionInt('hg.hostid', $hostIds, true) : '').
-			')'
-	);
-
-	$deletableGroupIds = [];
-	while ($dbRow = DBfetch($dbResult)) {
-		$deletableGroupIds[$dbRow['groupid']] = $dbRow['groupid'];
-	}
-
-	return $deletableGroupIds;
-}
-
 function isTemplate($hostId) {
 	$dbHost = DBfetch(DBselect('SELECT h.status FROM hosts h WHERE h.hostid='.zbx_dbstr($hostId)));
 
@@ -843,7 +766,7 @@ function isTemplate($hostId) {
  * @return array
  */
 function getInheritedMacros(array $hostids, ?int $parent_hostid = null): array {
-	$user_macro_parser = new CUserMacroParser();
+	$user_macro_parser = new CUserMacroParser(['allow_regex' => true]);
 
 	$all_macros = [];
 	$global_macros = [];
@@ -854,8 +777,12 @@ function getInheritedMacros(array $hostids, ?int $parent_hostid = null): array {
 	]);
 
 	foreach ($db_global_macros as $db_global_macro) {
-		$all_macros[$db_global_macro['macro']] = true;
-		$global_macros[$db_global_macro['macro']] = [
+		$user_macro_parser->parse($db_global_macro['macro']);
+		$minified_macro = $user_macro_parser->getMinifiedMacro();
+
+		$all_macros[$minified_macro] = true;
+		$global_macros[$minified_macro] = [
+			'macro' => $db_global_macro['macro'],
 			'value' => getMacroConfigValue($db_global_macro),
 			'description' => $db_global_macro['description'],
 			'type' => $db_global_macro['type']
@@ -882,74 +809,21 @@ function getInheritedMacros(array $hostids, ?int $parent_hostid = null): array {
 			$hosts[$hostid] = [
 				'templateid' => $hostid,
 				'name' => $db_template['name'],
-				'templateids' => zbx_objectValues($db_template['parentTemplates'], 'templateid'),
+				'templateids' => array_column($db_template['parentTemplates'], 'templateid'),
 				'macros' => []
 			];
 
-			/*
-			 * Global macros are overwritten by template macros and template macros are overwritten by host macros.
-			 * Macros with contexts require additional checking for contexts, since {$MACRO:} is the same as
-			 * {$MACRO:""}.
-			 */
-			foreach ($db_template['macros'] as $dbMacro) {
-				if (array_key_exists($dbMacro['macro'], $all_macros)) {
-					$hosts[$hostid]['macros'][$dbMacro['macro']] = [
-						'value' => getMacroConfigValue($dbMacro),
-						'description' => $dbMacro['description'],
-						'type' => $dbMacro['type']
-					];
-					$all_macros[$dbMacro['macro']] = true;
-				}
-				else {
-					$user_macro_parser->parse($dbMacro['macro']);
-					$tpl_macro = $user_macro_parser->getMacro();
-					$tpl_context = $user_macro_parser->getContext();
+			foreach ($db_template['macros'] as $db_macro) {
+				$user_macro_parser->parse($db_macro['macro']);
+				$minified_macro = $user_macro_parser->getMinifiedMacro();
 
-					if ($tpl_context === null) {
-						$hosts[$hostid]['macros'][$dbMacro['macro']] = [
-							'value' => getMacroConfigValue($dbMacro),
-							'description' => $dbMacro['description'],
-							'type' => $dbMacro['type']
-						];
-						$all_macros[$dbMacro['macro']] = true;
-					}
-					else {
-						$match_found = false;
-
-						foreach ($global_macros as $global_macro => $global_value) {
-							$user_macro_parser->parse($global_macro);
-							$gbl_macro = $user_macro_parser->getMacro();
-							$gbl_context = $user_macro_parser->getContext();
-
-							if ($tpl_macro === $gbl_macro && $tpl_context === $gbl_context) {
-								$match_found = true;
-
-								unset($global_macros[$global_macro], $hosts[$hostid][$global_macro],
-									$all_macros[$global_macro]
-								);
-
-								$hosts[$hostid]['macros'][$dbMacro['macro']] = [
-									'value' => getMacroConfigValue($dbMacro),
-									'description' => $dbMacro['description'],
-									'type' => $dbMacro['type']
-								];
-								$all_macros[$dbMacro['macro']] = true;
-								$global_macros[$dbMacro['macro']] = $global_value;
-
-								break;
-							}
-						}
-
-						if (!$match_found) {
-							$hosts[$hostid]['macros'][$dbMacro['macro']] = [
-								'value' => getMacroConfigValue($dbMacro),
-								'description' => $dbMacro['description'],
-								'type' => $dbMacro['type']
-							];
-							$all_macros[$dbMacro['macro']] = true;
-						}
-					}
-				}
+				$all_macros[$minified_macro] = true;
+				$hosts[$hostid]['macros'][$minified_macro] = [
+					'macro' => $db_macro['macro'],
+					'value' => getMacroConfigValue($db_macro),
+					'description' => $db_macro['description'],
+					'type' => $db_macro['type']
+				];
 			}
 		}
 
@@ -968,29 +842,31 @@ function getInheritedMacros(array $hostids, ?int $parent_hostid = null): array {
 	$parent_host_macros = [];
 
 	if ($parent_hostid !== null) {
-		$parent_host_macros = API::UserMacro()->get([
+		$db_macros = API::UserMacro()->get([
 			'output' => ['macro', 'type', 'value', 'description'],
 			'hostids' => [$parent_hostid]
 		]);
 
-		$parent_host_macros = array_column($parent_host_macros, null, 'macro');
-		$all_macros += array_fill_keys(array_keys($parent_host_macros), true);
-	}
+		foreach ($db_macros as $db_macro) {
+			$user_macro_parser->parse($db_macro['macro']);
+			$minified_macro = $user_macro_parser->getMinifiedMacro();
 
-	$all_macros = array_keys($all_macros);
-
-	// resolving
-	foreach ($all_macros as $macro) {
-		$inherited_macro = ['macro' => $macro];
-
-		if (array_key_exists($macro, $parent_host_macros)) {
-			$inherited_macro['parent_host'] = [
-				'value' => getMacroConfigValue($parent_host_macros[$macro]),
-				'description' => $parent_host_macros[$macro]['description'],
-				'type' => $parent_host_macros[$macro]['type']
+			$all_macros[$minified_macro] = true;
+			$parent_host_macros[$minified_macro] = [
+				'macro' => $db_macro['macro'],
+				'value' => getMacroConfigValue($db_macro),
+				'description' => $db_macro['description'],
+				'type' => $db_macro['type']
 			];
 		}
-		elseif (array_key_exists($macro, $global_macros)) {
+	}
+
+	// resolving
+	foreach (array_keys($all_macros) as $macro) {
+		$inherited_macro = [];
+
+		if (array_key_exists($macro, $global_macros)) {
+			$inherited_macro['macro'] = $global_macros[$macro]['macro'];
 			$inherited_macro['global'] = [
 				'value' => $global_macros[$macro]['value'],
 				'description' => $global_macros[$macro]['description'],
@@ -1005,6 +881,7 @@ function getInheritedMacros(array $hostids, ?int $parent_hostid = null): array {
 
 			foreach ($templateids as $templateid) {
 				if (array_key_exists($templateid, $hosts) && array_key_exists($macro, $hosts[$templateid]['macros'])) {
+					$inherited_macro['macro'] = $hosts[$templateid]['macros'][$macro]['macro'];
 					$inherited_macro['template'] = [
 						'value' => $hosts[$templateid]['macros'][$macro]['value'],
 						'description' => $hosts[$templateid]['macros'][$macro]['description'],
@@ -1036,6 +913,15 @@ function getInheritedMacros(array $hostids, ?int $parent_hostid = null): array {
 			$templateids = $parent_templateids;
 		} while ($templateids);
 
+		if (array_key_exists($macro, $parent_host_macros)) {
+			$inherited_macro['macro'] = $parent_host_macros[$macro]['macro'];
+			$inherited_macro['parent_host'] = [
+				'value' => $parent_host_macros[$macro]['value'],
+				'description' => $parent_host_macros[$macro]['description'],
+				'type' => $parent_host_macros[$macro]['type']
+			];
+		}
+
 		$inherited_macros[$macro] = $inherited_macro;
 	}
 
@@ -1091,7 +977,7 @@ function getInheritedMacros(array $hostids, ?int $parent_hostid = null): array {
  * @return array
  */
 function mergeInheritedMacros(array $host_macros, array $inherited_macros): array {
-	$user_macro_parser = new CUserMacroParser();
+	$user_macro_parser = new CUserMacroParser(['allow_regex' => true]);
 	$inherit_order = ['parent_host', 'template', 'global'];
 
 	foreach ($inherited_macros as &$inherited_macro) {
@@ -1131,8 +1017,9 @@ function mergeInheritedMacros(array $host_macros, array $inherited_macros): arra
 			if ($user_macro_parser->parse($host_macro['macro']) == CParser::PARSE_SUCCESS) {
 				$hst_macro = $user_macro_parser->getMacro();
 				$hst_context = $user_macro_parser->getContext();
+				$hst_regex = $user_macro_parser->getRegex();
 
-				if ($hst_context === null) {
+				if ($hst_context === null && $hst_regex === null) {
 					$host_macro['inherited_type'] = 0x00;
 				}
 				else {
@@ -1143,8 +1030,9 @@ function mergeInheritedMacros(array $host_macros, array $inherited_macros): arra
 						$user_macro_parser->parse($inherited_macro);
 						$inh_macro = $user_macro_parser->getMacro();
 						$inh_context = $user_macro_parser->getContext();
+						$inh_regex = $user_macro_parser->getRegex();
 
-						if ($hst_macro === $inh_macro && $hst_context === $inh_context) {
+						if ($hst_macro === $inh_macro && $hst_context === $inh_context && $hst_regex === $inh_regex) {
 							$match_found = true;
 
 							$host_macro = array_merge($inherited_macros[$inherited_macro], $host_macro);
@@ -1222,20 +1110,6 @@ function isReadableHosts(array $hostids) {
 	]);
 }
 
-/**
- * Check if user has read permissions for templates.
- *
- * @param array $templateids
- *
- * @return bool
- */
-function isReadableTemplates(array $templateids) {
-	return count($templateids) == API::Template()->get([
-		'countOutput' => true,
-		'templateids' => $templateids
-	]);
-}
-
 /**
  * Check if user has write permissions for hosts or templates.
  *
@@ -1318,19 +1192,6 @@ function renderInterfaceHeaders() {
 		);
 }
 
-function getHostDashboards(string $hostid, array $dashboard_fields = []): array {
-	$dashboard_fields = array_merge($dashboard_fields, ['dashboardid']);
-	$dashboard_fields = array_keys(array_flip($dashboard_fields));
-
-	$templateids = CApiHostHelper::getParentTemplates([$hostid])[1];
-
-	return API::TemplateDashboard()->get([
-		'output' => $dashboard_fields,
-		'templateids' => $templateids,
-		'preservekeys' => true
-	]);
-}
-
 /**
  * Return macro value to display in the list of inherited macros.
  *
@@ -1341,3 +1202,216 @@ function getHostDashboards(string $hostid, array $dashboard_fields = []): array
 function getMacroConfigValue(array $macro): string {
 	return ($macro['type'] == ZBX_MACRO_TYPE_SECRET) ? ZBX_SECRET_MASK : $macro['value'];
 }
+
+/**
+ * Format host prototype group links received via form for API input.
+ *
+ * @param array $group_links
+ *
+ * @return array
+ */
+function prepareHostPrototypeGroupLinks(array $group_links) {
+	foreach ($group_links as &$value) {
+		$value = ['groupid' => $value];
+	}
+	unset($value);
+
+	return $group_links;
+}
+
+/**
+ * Format host prototype group prototypes received via form for API input.
+ *
+ * @param array $group_prototypes
+ *
+ * @return array
+ */
+function prepareHostPrototypeGroupPrototypes(array $group_prototypes): array {
+	foreach ($group_prototypes as $i => &$group_prototype) {
+		if ($group_prototype['group_prototypeid'] === '') {
+			unset($group_prototype['group_prototypeid']);
+		}
+
+		if ($group_prototype['name'] === '') {
+			unset($group_prototypes[$i]);
+		}
+	}
+	unset($group_prototype);
+
+	return array_values($group_prototypes);
+}
+
+/**
+ * Format host prototype macros received via form for API input.
+ *
+ * @param array $macros
+ *
+ * @return array
+ */
+function prepareHostPrototypeMacros(array $macros): array {
+	foreach ($macros as &$macro) {
+		unset($macro['allow_revert'], $macro['discovery_state']);
+	}
+	unset($macro);
+
+	return $macros;
+}
+
+/**
+ * Format host prototype tags received via form for API input.
+ *
+ * @param array $tags
+ *
+ * @return array
+ */
+function prepareHostPrototypeTags(array $tags): array {
+	foreach ($tags as $i => $tag) {
+		if ($tag['tag'] === '' && $tag['value'] === '') {
+			unset($tags[$i]);
+		}
+	}
+
+	return array_values($tags);
+}
+
+/**
+ * Format host prototype interfaces received via form for API input.
+ *
+ * @param array $interfaces
+ *
+ * @return array
+ */
+function prepareHostPrototypeInterfaces(array $interfaces): array {
+	foreach ($interfaces as &$interface) {
+		if (array_key_exists('details', $interface)) {
+			$interface['details'] += ['bulk' => SNMP_BULK_DISABLED];
+		}
+	}
+	unset($interface);
+
+	return $interfaces;
+}
+
+/**
+ * Get sanitized host prototype fields of given input.
+ *
+ * Param array  $input
+ * Param string $input['templateid']
+ *
+ * @return array
+ */
+function getSanitizedHostPrototypeFields(array $input): array {
+	if ($input['templateid'] == 0) {
+		$field_names = ['host', 'name', 'custom_interfaces', 'status', 'discover', 'groupLinks',
+			'groupPrototypes', 'templates', 'tags' , 'macros', 'inventory_mode'
+		];
+
+		if ($input['custom_interfaces'] == HOST_PROT_INTERFACES_CUSTOM) {
+			$field_names[] = 'interfaces';
+
+			$input['interfaces'] = getSanitizedHostPrototypeInterfacesFields($input['interfaces']);
+		}
+	}
+	else {
+		$field_names = ['status', 'discover'];
+	}
+
+	return array_intersect_key($input, array_flip($field_names));
+}
+
+/**
+ * Get sanitized host prototype interface fields of given interfaces input.
+ *
+ * Param array  $interfaces
+ *
+ * @return array
+ */
+function getSanitizedHostPrototypeInterfacesFields(array $interfaces): array {
+	foreach ($interfaces as &$interface) {
+		$field_names = ['type', 'useip', 'ip', 'dns', 'port', 'main'];
+
+		if ($interface['type'] == INTERFACE_TYPE_SNMP) {
+			$field_names[] = 'details';
+
+			$interface['details'] = getSanitizedHostPrototypeInterfaceDetailsFields($interface['details']);
+		}
+
+		$interface = array_intersect_key($interface, array_flip($field_names));
+	}
+	unset($interface);
+
+	return $interfaces;
+}
+
+/**
+ * Get sanitized host prototype interface details fields of given details input.
+ *
+ * Param array  $details
+ *
+ * @return array
+ */
+function getSanitizedHostPrototypeInterfaceDetailsFields(array $details): array {
+	$field_names = ['version', 'bulk'];
+
+	switch ($details['version']) {
+		case SNMP_V1:
+			$field_names[] = 'community';
+			break;
+
+		case SNMP_V2C:
+			$field_names = array_merge($field_names, ['community', 'max_repetitions']);
+			break;
+
+		case SNMP_V3:
+			$field_names = array_merge($field_names,
+				['max_repetitions', 'contextname', 'securityname', 'securitylevel']
+			);
+
+			switch ($details['securitylevel']) {
+				case ITEM_SNMPV3_SECURITYLEVEL_AUTHNOPRIV:
+					$field_names = array_merge($field_names, ['authprotocol', 'authpassphrase']);
+					break;
+
+				case ITEM_SNMPV3_SECURITYLEVEL_AUTHPRIV:
+					$field_names = array_merge($field_names,
+						['authprotocol', 'authpassphrase', 'privprotocol', 'privpassphrase']
+					);
+					break;
+			}
+			break;
+	}
+
+	return array_intersect_key($details, array_flip($field_names));
+}
+
+/**
+ * Get summary interface availability status.
+ *
+ * @param array $interfaces
+ *
+ * @return int
+ */
+function getInterfaceAvailabilityStatus(array $interfaces): int {
+	$interfaces_with_enabled_items = array_filter($interfaces,
+		static fn ($interface) => $interface['has_enabled_items']
+	);
+
+	$interfaces = $interfaces_with_enabled_items ?: $interfaces;
+
+	$available = array_column($interfaces, 'available');
+
+	if (in_array(INTERFACE_AVAILABLE_MIXED, $available)) {
+		return INTERFACE_AVAILABLE_MIXED;
+	}
+
+	if (in_array(INTERFACE_AVAILABLE_FALSE, $available)) {
+		return in_array(INTERFACE_AVAILABLE_UNKNOWN, $available)
+				|| in_array(INTERFACE_AVAILABLE_TRUE, $available)
+			? INTERFACE_AVAILABLE_MIXED
+			: INTERFACE_AVAILABLE_FALSE;
+	}
+
+	return in_array(INTERFACE_AVAILABLE_UNKNOWN, $available)
+		? INTERFACE_AVAILABLE_UNKNOWN
+		: INTERFACE_AVAILABLE_TRUE;
+}
