@@ -1,6 +1,6 @@
 <?php
 /*
-** Copyright (C) 2001-2024 Zabbix SIA
+** Copyright (C) 2001-2026 Zabbix SIA
 **
 ** This program is free software: you can redistribute it and/or modify it under the terms of
 ** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
@@ -60,21 +60,6 @@ function HEX($var = null) {
 	return 'preg_match("/^([a-zA-Z0-9]+)$/",{'.$var.'})&&';
 }
 
-function validate_port_list($str) {
-	foreach (explode(',', $str) as $port_range) {
-		$port_range = explode('-', $port_range);
-		if (count($port_range) > 2) {
-			return false;
-		}
-		foreach ($port_range as $port) {
-			if (!validatePortNumber($port)) {
-				return false;
-			}
-		}
-	}
-	return true;
-}
-
 function calc_exp($fields, $field, $expression) {
 	if (strpos($expression, '{}') !== false) {
 		if (!isset($_REQUEST[$field])) {
@@ -503,35 +488,6 @@ function validateTimeSelectorPeriod($from, $to) {
 	}
 }
 
-function validatePortNumberOrMacro($port) {
-	return (validatePortNumber($port) || validateUserMacro($port));
-}
-
-function validatePortNumber($port) {
-	return validateNumber($port, ZBX_MIN_PORT_NUMBER, ZBX_MAX_PORT_NUMBER);
-}
-
-function validateNumber($value, $min = null, $max = null) {
-	if (!zbx_is_int($value)) {
-		return false;
-	}
-
-	if ($min !== null && $value < $min) {
-		return false;
-	}
-
-	if ($max !== null && $value > $max) {
-		return false;
-	}
-
-	return true;
-}
-
-function validateUserMacro($value) {
-	return (new CUserMacroParser())->parse($value) == CParser::PARSE_SUCCESS
-		|| (new CUserMacroFunctionParser())->parse($value) == CParser::PARSE_SUCCESS;
-}
-
 /**
  * Validate, if unix time in (1970.01.01 00:00:01 - 2038.01.19 00:00:00).
  *
