@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2026 Zabbix SIA
 **
 ** This program is free software: you can redistribute it and/or modify it under the terms of
 ** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
@@ -1866,18 +1866,22 @@ class CWidgetBase {
 			},
 
 			focusin: () => {
-				this.fire(WIDGET_EVENT_ENTER);
+				this.fire(WIDGET_EVENT_ENTER, {is_explicit: true});
 			},
 
 			focusout: () => {
 				this.fire(WIDGET_EVENT_LEAVE);
 			},
 
-			enter: () => {
-				this.fire(WIDGET_EVENT_ENTER);
+			mousemove: () => {
+				this.fire(WIDGET_EVENT_ENTER, {is_explicit: true});
 			},
 
-			leave: () => {
+			mouseenter: () => {
+				this.fire(WIDGET_EVENT_ENTER, {is_explicit: false});
+			},
+
+			mouseleave: () => {
 				this.fire(WIDGET_EVENT_LEAVE);
 			}
 		};
@@ -1893,10 +1897,11 @@ class CWidgetBase {
 			this._button_edit.addEventListener('click', this._events.edit);
 		}
 
-		this._target.addEventListener('mousemove', this._events.enter);
-		this._target.addEventListener('mouseleave', this._events.leave);
 		this._header.addEventListener('focusin', this._events.focusin);
 		this._header.addEventListener('focusout', this._events.focusout);
+		this._target.addEventListener('mousemove', this._events.mousemove);
+		this._target.addEventListener('mouseenter', this._events.mouseenter);
+		this._target.addEventListener('mouseleave', this._events.mouseleave);
 	}
 
 	/**
@@ -1909,10 +1914,11 @@ class CWidgetBase {
 			this._button_edit.removeEventListener('click', this._events.edit);
 		}
 
-		this._target.removeEventListener('mousemove', this._events.enter);
-		this._target.removeEventListener('mouseleave', this._events.leave);
 		this._header.removeEventListener('focusin', this._events.focusin);
 		this._header.removeEventListener('focusout', this._events.focusout);
+		this._target.removeEventListener('mousemove', this._events.mousemove);
+		this._target.removeEventListener('mouseenter', this._events.mouseenter);
+		this._target.removeEventListener('mouseleave', this._events.mouseleave);
 	}
 
 	/**
