@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2001-2024 Zabbix SIA
+** Copyright (C) 2001-2026 Zabbix SIA
 **
 ** This program is free software: you can redistribute it and/or modify it under the terms of
 ** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
@@ -134,7 +134,7 @@ class CWidgetNavTree extends CWidget {
 
 		if (new_item_id != 0 && this.#markTreeItemSelected(new_item_id)) {
 			this.#openBranch(this.#navtree_item_selected);
-			this.#updateUserProfile();
+			this.#updateUserProfileItemSelected();
 
 			return true;
 		}
@@ -418,9 +418,7 @@ class CWidgetNavTree extends CWidget {
 				}
 
 				if (this.getWidgetId() !== null) {
-					updateUserProfile(`web.dashboard.widget.navtree.item-${branch.getAttribute('data-id')}.toggle`,
-						closed_state, [this.getWidgetId()]
-					);
+					this.#updateUserProfileItemToggle(branch.getAttribute('data-id'), closed_state);
 
 					const index = this.#navtree_items_opened.indexOf(branch.getAttribute('data-id'));
 
@@ -488,21 +486,28 @@ class CWidgetNavTree extends CWidget {
 			this.#parseProblems();
 
 			if (!this.hasEverUpdated() && this.isReferred()) {
-				const item_selected = this.#getDefaultSelectable();
+				if (!this.#markTreeItemSelected(this.#navtree_item_selected)) {
+					this.#markTreeItemSelected(this.#getDefaultSelectable());
+					this.#openBranch(this.#navtree_item_selected);
 
-				if (this.#markTreeItemSelected(item_selected)) {
-					this.#updateUserProfile();
-					this.#broadcast();
+					this.#updateUserProfileItemSelected();
 				}
+
+				this.#broadcast();
 			}
-			else if (this.#navtree_item_selected !== null) {
-				this.#markTreeItemSelected(this.#navtree_item_selected);
+			else if (this.#navtree_item_selected !== null
+					&& !this.#markTreeItemSelected(this.#navtree_item_selected) && this.isReferred()) {
+				this.#markTreeItemSelected(this.#getDefaultSelectable());
+				this.#openBranch(this.#navtree_item_selected);
+
+				this.#updateUserProfileItemSelected();
+				this.#broadcast();
 			}
 		}
 	}
 
 	#getDefaultSelectable() {
-		return jQuery('.tree-item:visible', jQuery(this._target))
+		return jQuery('.tree-item[data-sysmapid]', jQuery(this._target))
 			.not('[data-sysmapid="0"]')
 			.first()
 			.data('id');
@@ -514,12 +519,18 @@ class CWidgetNavTree extends CWidget {
 		});
 	}
 
-	#updateUserProfile() {
+	#updateUserProfileItemSelected() {
 		updateUserProfile('web.dashboard.widget.navtree.item.selected',
 			this.#navtree_item_selected, [this.getWidgetId()]
 		);
 	}
 
+	#updateUserProfileItemToggle(itemid, closed_state) {
+		updateUserProfile(`web.dashboard.widget.navtree.item-${itemid}.toggle`,
+			closed_state, [this.getWidgetId()]
+		);
+	}
+
 	#removeTree() {
 		const root = this._target.querySelector('.root');
 
@@ -567,7 +578,8 @@ class CWidgetNavTree extends CWidget {
 		const selected_item = document.getElementById(`${this.getUniqueId()}_tree-item-${itemid}`);
 		const item = this.#navtree[itemid];
 
-		if (item === undefined || selected_item === null) {
+		if (item === undefined || selected_item === null
+				|| !selected_item.dataset.sysmapid || selected_item.dataset.sysmapid == 0) {
 			return false;
 		}
 
@@ -594,16 +606,15 @@ class CWidgetNavTree extends CWidget {
 			let $branch_to_open = jQuery(`.tree-item[data-id=${itemid}]`).closest('.tree-list').not('.root');
 
 			while ($branch_to_open.length) {
-				$branch_to_open.closest('.tree-item.is-parent')
-					.removeClass('closed')
-					.addClass('opened');
+				let $parent_item = $branch_to_open.closest('.tree-item.is-parent');
 
-				jQuery(selector, $branch_to_open.closest('.tree-item.is-parent'))
-					.removeClass('arrow-right')
-					.addClass('arrow-down');
+				$parent_item.removeClass('closed').addClass('opened');
 
-				$branch_to_open = $branch_to_open.closest('.tree-item.is-parent')
-					.closest('.tree-list').not('.root');
+				jQuery(selector, $parent_item).removeClass('arrow-right').addClass('arrow-down');
+
+				this.#updateUserProfileItemToggle($parent_item.data('id'), '0');
+
+				$branch_to_open = $parent_item.closest('.tree-list').not('.root');
 			}
 		}
 	}
@@ -734,16 +745,15 @@ class CWidgetNavTree extends CWidget {
 				}
 
 				overlayDialogue({
-					'title': t('Edit tree element'),
-					'class': 'modal-popup',
-					'content': content,
-					'buttons': [
+					title: t('Edit tree element'),
+					class: 'modal-popup',
+					content,
+					buttons: [
 						{
-							'title': item_edit ? t('Apply') : t('Add'),
-							'class': 'dialogue-widget-save',
-							'enabled': response.error === undefined,
-							'action': (overlay) => {
-								const form = document.getElementById('widget-dialogue-form');
+							title: item_edit ? t('Apply') : t('Add'),
+							enabled: response.error === undefined,
+							action: (overlay) => {
+								const form = document.forms['widget_item_form'];
 								const form_inputs = form.elements;
 								const url = new Curl('zabbix.php');
 
@@ -881,17 +891,19 @@ class CWidgetNavTree extends CWidget {
 
 								return false;
 							},
-							'isSubmit': true
+							isSubmit: true
 						},
 						{
-							'title': t('Cancel'),
-							'class': 'btn-alt',
-							'action': () => {}
+							title: t('Cancel'),
+							class: 'btn-alt',
+							action: () => {}
 						}
 					],
-					'dialogueid': 'navtreeitem',
-					'script_inline': response.script_inline
-				}, trigger_element);
+					script_inline: response.script_inline
+				}, {
+					dialogueid: 'navtreeitem',
+					trigger_element
+				});
 			}
 		});
 	}
@@ -1040,7 +1052,7 @@ class CWidgetNavTree extends CWidget {
 				if (this.#markTreeItemSelected(itemid)) {
 					this.#openBranch(this.#navtree_item_selected);
 
-					this.#updateUserProfile();
+					this.#updateUserProfileItemSelected();
 					this.#broadcast();
 				}
 
